Development
===========

pip is a volunteer maintained open source project and we welcome contributions
of all forms. The sections below will help you get started with development,
testing, and documentation.

You can also join ``#pypa`` (general packaging discussion and user support) and
``#pypa-dev`` (discussion about development of packaging tools) `on Freenode`_,
or the `pypa-dev mailing list`_, to ask questions or get involved.

.. toctree::
    :maxdepth: 2

    getting-started
    contributing
    release-process
    vendoring-policy

.. note::

    pip's development documentation has been rearranged and some older
    references might be broken.

.. _`on Freenode`: https://webchat.freenode.net/?channels=%23pypa-dev,pypa
.. _`pypa-dev mailing list`: https://groups.google.com/forum/#!forum/pypa-dev
